﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Json;
using System.Collections.ObjectModel;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;


namespace JSONNewYorkTimesTutorial
{
    public partial class Page : UserControl
    {
        private string myApiKey;
        private WebClient callNYT;

        public Page()
        {
            InitializeComponent();
            myApiKey = "&api-key=insert_your_key_here";
            callNYT = new WebClient();
            callNYT.OpenReadCompleted += new OpenReadCompletedEventHandler(callNYT_OpenReadCompleted);
        }

        private void PerformQuery(object sender, RoutedEventArgs e)
        {
            string NYTQueryBase = "http://api.nytimes.com/svc/search/v1/article";
            string SearchTerm = "?query=" + SearchText.Text;
            Uri queryUri = new Uri(NYTQueryBase + SearchTerm + myApiKey);

            callNYT.OpenReadAsync(queryUri);
        }

void callNYT_OpenReadCompleted(object sender, OpenReadCompletedEventArgs e)
{
    //grab our result and make a JSON Object out of it
    //    then extract the results array from that object
    JsonObject completeResult = (JsonObject)JsonObject.Load(e.Result);
    JsonArray resultsArray = (JsonArray)completeResult["results"];
    
    //an observable collection to hold the data and attach it to our ListBox
    ObservableCollection<NYTResult> resultCollection = new ObservableCollection<NYTResult>();

    //iterate through the results and transfer the data from a
    //   JSON object into our nice pretty .NET object
    foreach (JsonObject NYTRawResult in resultsArray)
    {
        NYTResult singleResult = new NYTResult();
        //don't forget to check your results... an article might not have a 
        //  byline or a link
        if (NYTRawResult.Keys.Contains("body")) 
            singleResult.Body = NYTRawResult["body"];
        if(NYTRawResult.Keys.Contains("byline"))
            singleResult.Byline = NYTRawResult["byline"];
        if (NYTRawResult.Keys.Contains("date")) 
            singleResult.Date = singleResult.formattedDateTime(NYTRawResult["date"]);
        if (NYTRawResult.Keys.Contains("title")) 
            singleResult.Title = NYTRawResult["title"];
        if (NYTRawResult.Keys.Contains("url")) 
            singleResult.Url = new Uri(NYTRawResult["url"]);
        
        //add our new result to the collection
        resultCollection.Add(singleResult);
    }

    //assign the result as the source for our ListBox
    ResultsDisplay.ItemsSource = resultCollection;

    //take the overall article count and display it
    resultCount.Text = "Number of articles: " + completeResult["total"].ToString();
}
    }
}
